// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

using Microsoft.AspNetCore.Mvc;

namespace BasicWebSite.Components;

public class ViewDataViewComponent : ViewComponent
{
    public IViewComponentResult Invoke() => View();
}
